@@ -2,7 +2,6 @@
 # -*- coding: UTF-8 -*-
 # flake8: noqa
 import typic as __
-from docs import plays
-from . import ast, parse, render, roman
+from . import ast, parse, plays, render, roman
 
 SCHEMA = __.schemas()
